# what it's called on pypi
%global pypi_name trio
# what it's imported as
%global libname %{pypi_name}
# name of egg info directory
%global eggname %{pypi_name}
# package name fragment
%global pkgname %{pypi_name}

%global common_description %{expand:
The Trio project's goal is to produce a production-quality, permissively
licensed, async/await-native I/O library for Python.  Like all async libraries,
its main purpose is to help you write programs that do multiple things at the
same time with parallelized I/O.  A web spider that wants to fetch lots of
pages in parallel, a web server that needs to juggle lots of downloads and
websocket connections at the same time, a process supervisor monitoring
multiple subprocesses... that sort of thing.  Compared to other libraries, Trio
attempts to distinguish itself with an obsessive focus on usability and
correctness.  Concurrency is complicated; we try to make it easy to get things
right.}

%bcond_with  tests

Name:       python-%{pkgname}
Version:    0.25.0
Release:    %mkrel 1
Summary:    A friendly Python library for async concurrency and I/O
License:    MIT or ASL 2.0
Group:      Development/Python
URL:        https://pypi.org/project/trio/
Source0:    %{pypi_source}
BuildArch:  noarch


%description %{common_description}


%package -n python3-%{pkgname}
Summary:        %{summary}
Group:      Development/Python
BuildRequires: pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3dist(setuptools)
%if %{with tests}
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pyopenssl)
BuildRequires:  python3dist(trustme)
BuildRequires:  python3dist(attrs)
BuildRequires:  python3dist(sortedcontainers)
BuildRequires:  python3dist(async-generator)
BuildRequires:  python3dist(idna)
BuildRequires:  python3dist(outcome)
BuildRequires:  python3dist(sniffio)
%endif
%{?python_provide:%python_provide python3-%{pkgname}}


%description -n python3-%{pkgname} %{common_description}


%prep
%autosetup -n %{pypi_name}-%{version} -p 1


%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files trio


%if %{with tests}
%check
%pytest --verbose trio/_core/tests
%endif


%files -n python3-%{pkgname} -f %{pyproject_files}
%license LICENSE LICENSE.MIT LICENSE.APACHE2
%doc README.rst



%changelog
* Mon Jul 29 2024 papoteur <papoteur> 0.25.0-1.mga10
+ Revision: 2082880
- new version 0.25.0

* Sat Dec 09 2023 wally <wally> 0.22.0-2.mga10
+ Revision: 2016479
- rebuild for py3.12

* Sat Nov 19 2022 guillomovitch <guillomovitch> 0.22.0-1.mga9
+ Revision: 1908846
- new version 0.22.0

* Wed Sep 07 2022 neoclust <neoclust> 0.21.0-1.mga9
+ Revision: 1885347
- New version  0.21.0

* Sun Mar 20 2022 guillomovitch <guillomovitch> 0.20.0-1.mga9
+ Revision: 1808837
- new version 0.20.0

* Sat Feb 12 2022 wally <wally> 0.19.0-2.mga9
+ Revision: 1773474
- rebuild for python3.10
- disable tests for now

* Sun Aug 22 2021 guillomovitch <guillomovitch> 0.19.0-1.mga9
+ Revision: 1742326
- new version 0.19.0

* Sun Mar 21 2021 guillomovitch <guillomovitch> 0.18.0-1.mga9
+ Revision: 1706674
- new version 0.18.0

* Sun Jan 17 2021 guillomovitch <guillomovitch> 0.16.0-1.mga8
+ Revision: 1672173
- imported package python-trio

